@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0506';
+our $VERSION = '0.0507';
 
 use Moo;
 use strictures 2;
@@ -123,6 +123,10 @@ sub generate {
     $num   ||= 4;
 
     my ($chord_note, $flavor) = _parse_chord($chord);
+    if ($flavor =~ /^\//) {
+        $flavor = '';
+        $chord  = $chord_note;
+    }
 
     my $next_chord_note;
     ($next_chord_note) = _parse_chord($next_chord)
@@ -296,7 +300,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0506
+version 0.0507
 
 =head1 SYNOPSIS
 
@@ -514,7 +518,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2022 by Gene Boggs.
+This software is Copyright (c) 2023 by Gene Boggs.
 
 This is free software, licensed under:
 
